#
# spec file for package amarok
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with ffmpeg

Name:           amarok
Version:        2.6.0
Release:        2.38
Summary:        Media Player for KDE
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Players

Url:            http://amarok.kde.org/
Source0:        ftp://ftp.kde.org/pub/kde/stable/%{name}/%{version}/src/%{name}-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE initial-preference.diff bnc#605522 llunak@novell.com -- Increase initial preference to be used for audio files instead of Kaffeine
Patch1:         initial-preference.diff
# PATCH-FIX-OPENSUSE flac_mimetype_bnc671581.diff bnc#671581 ctrippe@gmx.net -- Support for the changed mimetype for flac files
Patch2:         flac_mimetype_bnc671581.diff
Patch3:         revert_solid_workaround.diff
Patch4:         liblastfm1-support.diff
# PATCH-FIX-UPSTREAM fix-transcoding.patch kde#309454 -- Fix available transcoding encoders with ffmpeg >= 1.0
Patch5:         fix-transcoding.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

# Required for the fdupes macro
BuildRequires:  fdupes
BuildRequires:  gdk-pixbuf-devel
BuildRequires:  glib2-devel
BuildRequires:  libcurl-devel
%if %{with ffmpeg}
BuildRequires:  libffmpeg-devel
BuildRequires:  libofa-devel
%endif
BuildRequires:  libgcrypt-devel
BuildRequires:  libgpod-devel >= 0.7.0
BuildRequires:  libkde4-devel >= 4.6.0
BuildRequires:  liblastfm-devel
BuildRequires:  libmtp-devel
BuildRequires:  libmygpo-qt-devel >= 1.0.5
BuildRequires:  libmysqlclient-devel
BuildRequires:  libmysqld-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libqca2-devel
BuildRequires:  libqjson-devel
BuildRequires:  loudmouth-devel
BuildRequires:  qt4-qtscript
BuildRequires:  taglib-devel
BuildRequires:  taglib-extras-devel
BuildRequires:  tcpd-devel
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
Requires:       libtag-extras1 >= 1.0
Requires:       taglib >= 1.6
%kde4_runtime_requires
Recommends:     moodbar
Recommends:     qt4-qtscript
Recommends:     %{name}-lang = %{version}
Provides:       kde4-amarok = 2.0.90
Obsoletes:      kde4-amarok <= 2.0.89

%description
Amarok is a media player for all kinds of media. This includes MP3, Ogg
Vorbis, audio CDs, podcasts and streams. Play lists can be stored in
.m3u or .pls files.

%lang_package
%prep
%setup -q
%patch1
%patch2
%patch3 -p1
if [ $(rpm -q --qf '%{VERSION}' liblastfm-devel | cut -c 1) -gt 0 ]; then
%patch4 -p1
fi
%patch5 -p0

# Remove build time references so build-compare can do its work
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
sed -i "s/__DATE__/\"$FAKE_BUILDDATE\"/" src/main.cpp

%build
%ifarch ppc ppc64
export RPM_OPT_FLAGS="%{optflags} -mminimal-toc"
%endif
%cmake_kde4 -d build
%make_jobs

%install
cd build
%kde4_makeinstall
cd ..

# Remove *.so files (not needed), fix "devel-file-in-non-devel-package" rpmlint warning
# "libampache_account_login.so" should not be removed
rm -f %{buildroot}%{_kde4_libdir}/libamarok{core,lib,ocsclient,pud,-sqlcollection,-transcoding}.so

#bnc722284 amarok is not really a good player for audio-cds, remove the action for solid
rm -f %{buildroot}%{_kde4_appsdir}/solid/actions/amarok-play-audiocd.desktop

%if 0%{?suse_version}
%suse_update_desktop_file amarok Qt KDE AudioVideo Audio Player
%endif

# Remove unneeded locales
%if 0%{?suse_version} && 0%{?suse_version} < 1140
rm -rf %{buildroot}%{_datadir}/locale/sr@ijekavian/
rm -rf %{buildroot}%{_datadir}/locale/sr@ijekavianlatin/
%endif

%fdupes -s %{buildroot}

%find_lang amarok
%find_lang amarokcollectionscanner_qt amarok.lang
%find_lang amarok_scriptengine_qscript amarok.lang
%find_lang amarokpkg amarok.lang

%kde_post_install

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING* ChangeLog README TODO
%{_kde4_bindir}/amarok
%{_kde4_bindir}/amarok_afttagger
%{_kde4_bindir}/amarokcollectionscanner
%{_kde4_bindir}/amarokmp3tunesharmonydaemon
%{_kde4_bindir}/amarokpkg
%{_kde4_modulesdir}/amarok_*
%{_kde4_modulesdir}/kcm_amarok_service_*
%{_kde4_libdir}/libamarok-sqlcollection.so.*
%{_kde4_libdir}/libamarok-transcoding.so.*
%{_kde4_libdir}/libamarokcore.so.*
%{_kde4_libdir}/libamaroklib.so.*
%{_kde4_libdir}/libamarokocsclient.so.*
%{_kde4_libdir}/libamarokpud.so.*
%{_kde4_libdir}/libampache_account_login.so
%{_kde4_applicationsdir}/amarok.desktop
%{_kde4_applicationsdir}/amarok_containers.desktop
%{_datadir}/dbus-1/interfaces/org.freedesktop.MediaPlayer.player.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.MediaPlayer.root.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.MediaPlayer.tracklist.xml
%{_datadir}/dbus-1/interfaces/org.kde.amarok.App.xml
%{_datadir}/dbus-1/interfaces/org.kde.amarok.Collection.xml
%{_datadir}/dbus-1/interfaces/org.kde.amarok.Mpris1Extensions.Player.xml
%{_datadir}/dbus-1/interfaces/org.kde.amarok.Mpris2Extensions.Player.xml
%{_kde4_iconsdir}/hicolor/*/apps/amarok.*
%{_kde4_appsdir}/amarok/
%dir %{_kde4_appsdir}/desktoptheme
%dir %{_kde4_appsdir}/desktoptheme/default
%dir %{_kde4_appsdir}/desktoptheme/default/widgets
%{_kde4_appsdir}/desktoptheme/default/widgets/amarok-*
%{_kde4_appsdir}/kconf_update/amarok-2.4.1-tokens_syntax_update.pl
%{_kde4_appsdir}/kconf_update/amarok.upd
%{_kde4_sharedir}/config.kcfg/amarokconfig.kcfg
%{_kde4_configdir}/amarok*
%{_kde4_servicesdir}/ServiceMenus/amarok_append.desktop
%{_kde4_servicesdir}/amarok-*
%{_kde4_servicesdir}/amarok_*
%{_kde4_servicesdir}/amarok.protocol
%{_kde4_servicesdir}/amarok*.protocol
%{_kde4_servicetypesdir}/amarok_*

%files lang -f amarok.lang
%defattr(-,root,root,-)

%changelog
* Thu Dec 27 2012 fisiu@opensuse.org
- Add fix-transcoding.patch - fixes #PM-57.
* Sun Dec 16 2012 stefan.bruens@rwth-aachen.de
- fix broken signal/slot signatures caused by SR:130759
* Fri Nov  2 2012 ctrippe@opensuse.org
- Install the english handbook only with the lang-package as otherwise
  translations will not be displayed when they are provided by
  bundle-lang-kde-* (bnc#695108)
- No longer Build-require libksuseinstall-devel as the corresponding
  patch was removed
* Thu Sep  6 2012 dmueller@suse.com
- add support for liblastfm1
  * liblastfm1-support.diff
* Tue Aug 14 2012 toddrme2178@gmail.com
- Remove ksuseinstall patch entirely
* Mon Aug 13 2012 toddrme2178@gmail.com
- Update to 2.6
  * See http://strohel.blogspot.com/2012/08/amarok-26-released-enjoy-great-ipod.html
- Removed obsolete version checks
- Remove upstream implemented patches
- Temporarily disabled non-working ksuseinstall patch
- Rebased patches
* Fri Jun 15 2012 stefan.bruens@rwth-aachen.de
- remove errmsg patch, it must match the version of the installed
  libmysqld, thus libmysqld need a matching dependency
  depends on fixed mysql package
  fixes bnc#712749
* Mon May 28 2012 reddwarf@opensuse.org
- Fix build with ffmpeg 0.11
* Tue Mar  6 2012 stefan.bruens@rwth-aachen.de
- Revert: Fix detection of mounts of NFS & SMB Shares
  depends on fix in solids mtab handling, available with SC 4.8.2
* Wed Feb  1 2012 tittiatcoke@gmail.com
- Enable proper script support again as that qt4-qtscript now
  compiles for Qt 4.8
* Fri Jan 27 2012 idonmez@suse.com
- Add patch to fix kde#290123
* Tue Dec 20 2011 adrian@suse.de
- Update to final version 2.5.0
  * Mainly bugfixes since Beta 1, check the ChangeLog file for details
* Mon Dec 12 2011 idonmez@suse.com
- Fix path to errmsg.sys
* Fri Dec  9 2011 dmueller@suse.de
- remove qt4-qtscript dependency
* Wed Nov 30 2011 mlin@suse.com
- Add amarok-fix-infinite-loop-eating-CPU.diff
  * Fix infinite loop in context view eating CPU until main
    window is shown (bnc#733421)
* Tue Nov 15 2011 tittiatcoke@gmail.com
- Update to 2.5 Beta 1 (2.4.90)
  * New "equals" match in collection filter
  * Enable dropping tracks on empty area in Saved Playlists to
    create new playlist.
  * Added a "create new playlist" action in the empty space of the
    Saved Playlists. (bko#202725)
  * Add new type of optional tokens in format string
    (Collection Organizer) (bko#264874)
  * Music store based on the Amazon catalogue.
  * Auto-save the playlist so that it is not lost if Amarok
    crashes.
  * Both Delete and Move to Trash actions are now offered in the
    collection browser context menu. (bko#286356)
  * New USB Mass Storage media-device plugin using the Amarok
    Collection Scanner.
  * Playlist: Don't group albums without name. (bko#243344)
  * Total rewrite of Automated Playlist Generator algorithm.
  * Several bugfixes
* Sun Nov  6 2011 ctrippe@opensuse.org
- Change ksuseinstall to support the gstreamer-backend instead of
  the xine one (bnc#728476)
* Fri Oct  7 2011 ctrippe@opensuse.org
- Remove errmsg-mysql51-embedded.diff as this causes amarok to fail
  when initializing the collection (bnc#712749)
- Remove the action for audio-cds as amarok is not really a good
  player for these (bnc#712749)
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Mon Aug 29 2011 idonmez@suse.com
- Don't disable ksuseintall & liblastfm support for KDE:UpdatedApps
* Tue Aug  9 2011 reddwarf@opensuse.org
- Optionally enable MusicDNS support (requires ffmpeg/libav)
* Mon Aug  1 2011 asterios.dramis@gmail.com
- Update to 2.4.3:
  Bugfixes:
  * Fix KWallet auth requests on every track change. (bko#278177)
  * Display correct values for pretty times (playlist length) > 1 day.
  * Update playlist length correctly after removing track. (bko#273407)
  * Fix seek backward from dbus. (Thanks to Matthieu Bedouet) (bko#263287)
  * Prevent dialog querying last.fm settings being displayed on startup if
    none set.
  * Fix detection of smartphones in USB storage mode. (bko#277685)
  * Fix crashes on expanding a newly cloned dynamic playlist (bko#277750)
  * Don't block the UI while calculating the filename previews. (bko#233196)
  * Make M3U & PLS playlist files editable from Saved Playlists. (bko#245963)
  From 2.4.2-Beta 1:
  Features:
  * Made Amarok compile with the Clang LLVM frontend.
  * Enable drag and drop on collections to copy/move within Local Music and
    directly from the playlist. (bko#223400)
  * Added KNotify scripting interface. (bko#260750)
  * Make podcast episodes download filename configurable. Patch by
    Sandeep Raghuraman. (bko#155075)
  * Automatic scrolling in lyrics applet (Thanks to Jan Gerrit Marker)
  * Option to scrobble composer as artist to Last.fm (Thanks to Nicholas
    Wilson)
  * Option to hide the OSD if another window is taking the full screen
  Changes:
  * Again write back ratings only if option is selected.
  * Moved the queue-editor action to the main menu under playlist to save
    space. Queue editor now has a shortcut: Meta+U.
  * Removed the redo action from the playlist toolbar to make it less wide.
  * Made some playlist toolbar actions collapse into a menu button for use on
    small screens.
  * Removed the statusbar. Moved progress info & messages to the Media
    Sources dock.
  * Removed the preview button and checkbox from the organize collection
    dialog.
  * General user interface cleanup (addition of browser widget backgrounds,
    etc.)
  * Removed the add button in the context toolbar. Applet explorer is opened
    on config.
  * Easier to understand Dynamic playlists
  * Made Amarok depend ffmpeg-0.6 or newer.
  * Use KImageCache if possible (kdelibs 4.5.0 and later), which should
    reduce the number of cache-related crashes.
  Bugfixes:
  * Make the Coverbling applet build again. (Patch by Manu Wagner)
  * Don't let the album applet freeze Amarok for ages on track change.
    (bko#260810, bko#277021)
  * Fixed cover fetching from Google Images. (bko#275265)
  * Fixed a crash in the equalizer dialog when selecting "Off".
  * Fix finalization of track copy process to media device collections.
    (bko#238912) Patch by Tommaso Falchi Delitala.
  * Fixed crash on MusicBrainz search. (bko#274956)
  * Avoid crash in ContextView when accessing Plasma::Applet::view().
    (bko#258741)
  * Fixed playlist tooltip getting too tall for multiline comments.
    (bko#256038)
  * Made equalizer keywords (dB,kHz,...) translatable. (bko#263572)
  * Made equalizer preset names translatable. (bko#263596)
  * Fixed runtime error reporting of scripts. (bko#207409)
  * Fixed "Happy" moodbar theme. (bko#264432)
  * Fixed crash for invalid scripts trying to be stopped by the manager.
    (bko#268917)
  * Fixed collection menu items ordering. (bko#207007)
  * Fixed top level podcast location setting. (bko#263736)
  * Fixed double-clicking in collection using left-handed mouse setting.
    (bko#272360)
- Removed remove-plasma-service.patch that fixed build with KDE 4.7 rc2 (fixed
  upstream).
- Rebased ksuseinstall.diff patch to apply cleanly.
* Thu Jul 21 2011 idoenmez@suse.de
- Enable libmygpo-qt. Remove deprecated conditions
* Tue May 10 2011 wstephenson@novell.com
- Amarok 2.4.1:
  - Features:
  * Remote NFS & SMB/CIFS collections now work! (bko#249760, bko#232976, bko#171213, bko#187692)
  * New "Preview" feature for the Organize Collection dialog
  * String filtering in the albums applet.
  * Ability to change text alignment in the lyrics applet.
  * gpodder.net Service, a Podcast Directory displaying the most used Tags from gpodder.net & the top Podcasts of these Tags
  - Changes:
  * The podcast directory service is now based on incremental parsing of OPML without caching in the database.
  * Plugins can now be optionally enabled in the config dialog
  * Script selector is moved from the menubar to the config dialog.
* Wed Apr 27 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Cleanup in Buildrequires: entries.
  * Added description for the patches based on openSUSE Patches Guidelines.
  * Removed amarok-devel subpackage since the package doesn't actually provides
    any shared libraries. Also removed some *.so libraries to fix rpmlint
    warning "devel-file-in-non-devel-package".
  * Added "Audio" to the Categories entry of amarok.desktop file.
  * Moved english help files in the main package.
  * Updates in %%files section.
  * Minor other updates.
- Removed amarok-rpmlintrc (not needed).
- Removed amarokNoAudio.desktop from initial-preference.diff patch (since it
  was not used).
- Removed errmsg-mysql-embedded.diff patch (not needed for openSUSE > 11.0).
- Removed no_buildtime.patch and added a fix inside the spec file.
* Sat Mar 19 2011 wstephenson@novell.com
- Update to 2.4.0.90 (2.4.1beta1)
- Remove amarok-e1aa6497-missing-toolbar-fresh-start.diff (uptream)
* Tue Feb 15 2011 ctrippe@gmx.net
- Support for the changed mimetype for flac files (bnc#671581)
* Tue Feb  8 2011 ctrippe@gmx.net
- Recommend the amarok-lang package (bnc#661855)
* Sat Jan 29 2011 wstephenson@novell.com
- Fix missing main toolbar on first run (bko#248690)
* Tue Jan 11 2011 wstephenson@novell.com
- Update to 2.4.0
  * New splashscreen
  * Playdar collection type disabled pending bug fixes
  * Fixed broken radio stream URLs
  * Fix crash on copying tracks between collections (bko#261364)
  * Fix fetching of script data (bko#261839)
  * Leave pending files in case of conflicts or errors while moving
    tracks (bko#257739)
  * Fix issue with UMS Collection that made amarok delete original
    track instead of newly copied one. (bko#238915)
  * Fixed issue with Audio CDs that do not provide CDDB information.
    Patch by Andriy Gapon <avg@icyb.net.ua>. (bko#257818)
  * Fixed issue with the Organize Files Dialog that prevented
    presets from being loaded when in advanced mode. Patch by
    Philipp Schmidt <philschmidt@gmx.net>.  (bko#255325)
    on the network.
* Sat Jan  1 2011 rwooninck@opensuse.org
- Changed the patchfile for the embedded mysql server (bnc#661950)
* Mon Dec 13 2010 tittiatcoke@gmail.com
- Update to 2.3.90 (2.4 Beta 1)
  New Features:
  * New UPnP Collection detects and plays media on UPnP devices
  * Mass-tagging UI using Musicbrainz
  * The ability to use iPod Touch 3G and possibly newer devices
  * A new applet for guitar and bass tab information
  * A map and calendar view for the upcoming events applet
  * A new Playdar collection that lets you listen to music
    provided by a local Playdar service
  * Transcoding: Now you can convert tracks from one file format
    to another when copying from the file browser to the local
    collection. We will expand this to media devices in future
    releases.
  * Shiny new collection scanner, rewritten from scratch - it
    should now detect compilations in a more robust way
  * Writing back to tags: there is now an option to have Amarok
    write statistics and album covers to the files directly, so
    you can save your play counts and tags in the files themselves.
* Fri Sep 24 2010 wstephenson@novell.com
- Fix invalid characters in id3 tags ending up in database due to
  new tag processing code (bnc#251762)
* Fri Sep 24 2010 coolo@novell.com
- update to 2.3.2
  * Bumped libMTP dependency to version 1.0.0.
  * Improved response of current track and albums applet on data updates.
  * Use system date/time format for default name when saving user playlists.
  * Many bug fixes
* Wed Aug 25 2010 coolo@novell.com
- fix build in reordering includes for qt and gdk (later uses
  "signals")
* Fri Aug 13 2010 vuntz@opensuse.org
- Drop unneeded libnjb-devel BuildRequires.
* Sat Jul 17 2010 reddwarf@opensuse.org
- Remove optional libmp4v2-devel dependency. Not needed anymore.
* Fri Jun 25 2010 tittiatcoke@gmail.com
- Update to 2.3.1 Final
  * Automated Playlist Generator
  * New Applets for Context View (Upcoming Events & Similar Artists)
  * Many improvements for Cover Fetching
  * support for the new System Tray Protocol
  * See http://amarok.kde.org/en/releases/2.3.1
* Fri Jun 25 2010 beineri@opensuse.org
- fix build for <11.3
* Mon Jun 21 2010 cmorve69@yahoo.es
- Make it the default media player ONLY for audio files
* Thu May 13 2010 llunak@novell.com
- increase initial preference to be used for audio files
  instead of Kaffeine (bnc#605522)
* Thu Apr  1 2010 llunak@novell.com
- support for on-demand codecs install using ksuseinstall
* Thu Mar 25 2010 tittiatcoke@gmail.com
- Include patch for Info Applet to prevent crash
  (bko#229756, bko#227639)
* Thu Mar 11 2010 tittiatcoke@gmail.com
- Update to 2.3.0
  * Podcast channels and episodes can be dragged to add them to other
    providers. (bko#195704)
  * Track action buttons are now available in the label for the current track.
  * Bookmark button is now available in the Current Track applet.
  * When a podcast episode is no longer shown because of the episode limit,
    the downloaded file is also deleted from disk. (bko#227674)
  * Volume Dial: Gradient indicator and pointing cursor hint above the dial ring
  * The visibility of columns in the new Files Browser is now configurable.
  * Set Media Keys as default global shortcuts for playlist navigation.
    (bko#194259)
  * for detailed changes, see http://amarok.kde.org/en/releases/2.3 or
    the included ChangeLog
* Sun Feb 14 2010 wstephenson@novell.com
- update to 2.3 Beta 1
  * Improved podcast UI
  * New main toolbar
  * Use USB Mass Storage devices as collections automatically
  * Dynamic Collection
  * Last.fm interactive cover search
  * for detailed changes, see http://amarok.kde.org/en/releases/2.3/beta/1
* Mon Feb  1 2010 vuntz@opensuse.org
- Remove gdk-pixbuf-devel BuildRequires: amarok needs gdk-pixbuf2
  which is in gtk2-devel.
* Tue Jan 12 2010 tittiatcoke@gmail.com
- included the patch to prevent Amarok from a crash during scanning.
* Sat Jan  9 2010 tittiatcoke@gmail.com
- update to 2.2.2
  * see for detailed changelog : http://amarok.kde.org/en/releases/2.2.2
  * The inline playlist editor now also allows resizing of auto sized items
    that are invisible because fixed sized items already use up 100%% width.
  * Enhanced the playlist sorting breadcrumb items to separately highlight
    the order inversion arrow on hover. (bko#209011)
  * The automatic character set detection for tags has been disabled; it
    caused too many problems with legitimate UTF-8 tags. It can be
    re-enabled from Settings->Collection. (Many BRs)
  * Dynamic mode is now automatically disabled when replacing the playlist.
    (bko#214759)
  * The collection search filter now also searches for file names as a
    fallback. Patch by Andreas Hartmetz <ahartmetz@gmail.com>.
  * Fixed loading MusicBrainz-tagger tracks in dynamic playlists (bko#219902)
  * Fixed crash when trying to play a media device track whose collection
    no longer exists (bko#210477)
  * Other bugfixes
* Thu Dec 17 2009 tittiatcoke@gmail.com
- Update to 2.2.2 Beta 1
  * See for detailed changelog : http://amarok.kde.org/en/releases/2.2.2/beta/1
  * Tracks in Albums applet are now sorted by track number.
  * New menu to add applets to the context view.
  * Moved the "Playlist Layout" button into the main menu, as the playlist
    toolbar was becoming too crowded.
  * New interface for repeat and random playback modes. Interface now correctly
    represents the actual behaviour (ony one mode can be active at any time)
    and is accessible directly from the playlist toolbar.
  * Usability: Added tooltips all over the place, improved existing ones.
  * Improved automatic resizing of lyrics and suggestions in the context applet.
* Sun Nov 29 2009 cmorve69@yahoo.es
- Patch to remove build time from code
* Mon Nov 16 2009 tittiatcoke@gmail.com
- Added fix for the default playlist layout
* Sat Nov 14 2009 tittiatcoke@gmail.com
- Update to 2.2.1
  - Removed patch to handle x-vorbis+ogg (included upstream)
  * Podcasts will only be automatically updated when there is a network
    connection (using Solid)
  * The SMB (Samba) protocol is now supported in the playlist. Patch by
    Steven van der Vegt <s.vandervegt@student.utwente.nl>. (bko#178691)
  * CTRL+SHIFT+F toggles full screen mode. Patch by Rick W. Chen
    <stuffcorpse@archlinux.us>
  * Playlist files can be droped on the "Saved Playlist" category to
    import them into Amarok. (bko#193476)
  * Middle-clicking an item in the Collection Browser appends it to the
    playlist. Patch by Felix Geyer <debfx-kde@fobos.de>. (bko#197423)
  * Added feature for removing duplicates from the playlist. Patch by John
    Atkinson <john@fauxnetic.co.uk>. (bko#200445)
  * Allow changing of playlist layout item sizes using the inline editor.
  * Initial KNotify support.
  * Show total playlist file size in a tooltip when hovering over the total
    play list time. (bko#91640)
  * Implemented "Jump To". Press Ctrl+J to focus the playlist search.
    (bko#92400)
  * Made Love/Skip/Ban/Enqueue/Dequeue available in Shortcuts configuration
    dialog. (bko#136232, bko#187542)
  * Many more fixes and changes. See ChangeLog for more information
* Wed Oct 14 2009 saigkill@opensuse.org
- Tweaked the Package in -devel
- fixed some RPMLint Errors
- added rpmlintrc
- reworked handle-x-vorbis+ogg.diff (New created with quilt)
* Fri Oct  9 2009 saigkill@opensuse.org
- added handle-x-vorbis+ogg.diff (Based on an Proposal on the amarok-users List.)
* Wed Sep 30 2009 tittiatcoke@gmail.com
- update to 2.2.0 final: several bugfixes and
  * The MusicBrainz ID of a track is now scrobbled to Last.fm, if it exists
    (kde#122281)
  * More collection scanning speedups.
  * Replay gain works on the Phonon Xine backend.
  * Fadeout on track end works again.
  * Fixed regression where the last album to be scanned would not have its
    cover picked up by the collection scanner.
  * Sorting by track length in the playlist is now possible (kde#208689)
  * Fixed track bookmarks not immediately getting removed from progress bar
    when they are deleted from the bookmark manager.
  * Fixed new track bookmarks not getting shown in the progress bar
    immediately.
  * Fixed track bookmarks not getting correctly repainted when resizing
    progress bar. (kde#207091)
  * Correct a logic bug during incremental scanning that could cause the
    wrong tracks to be removed from the collection, requiring a full rescan.
    Should fix bug 208403 and likely multiple others. (kde#208403)
  * "Configure Amarok" dialog takes up less space, making it suitable for
    small screens.
  * Fixed photos applet not working after resuming playback. (kde#206829)
  * Fixed regression where the genre field in the Tag Dialog would show the
    composer of the track. (kde#208255)
  * Don't reshuffle the playlist every time the active track changes when
  * using a random sort order.
  * Fixed the Various Artist node sometimes being shown in the Collection
    Browser with nothing underneath it (or an empty "Unknown" album).
  * Fixed some tracks' tags not being saved correctly to the database.
    (kde#202021)
* Tue Sep 22 2009 beineri@opensuse.org
- update to 2.2 RC 1: several bugfixes and
  * Import itpc:// podcast urls
  * Mark podcast episode as not-new when starting to play it
  * Reintroduced indicator icons for new podcast episodes
  * Added "subscribe" command line switch to add a podcast channel
  * Removed Shoutcast service due to technical & other issues
  * Made audio CDs respect "Automatically retrieve cover art" setting.
  * TagLib 1.6 built with ASF & MP4 support is now required. This
    release fixes many, many bugs and contains new format support.
  * TagLib-Extras 1.0.0 is now required. This release is compatible
    with the new TagLib 1.6 release.
  * Removed non working menu entry "rename" from the Bookmark Manager.
    Functionality is no longer needed as inline renaming is possible.
  * Improvements for volume widget in ToolbarNG.
  * Added "Lock layout" option to the main window's context menu.
* Tue Sep 15 2009 beineri@opensuse.org
- Update to 2.2 Beta 2: several bugfixes and
  * Added DBus methods Forward and Backward for relative seeking
    and PlayPause for toggling pause state
  * Grouping mode has been merged into the playlist layouts so each
    layout sets its own. The default grouping mode for layout files
    that do not have this value explicitly set is "Album".
* Sun Sep 13 2009 cmorve69@yahoo.es
- update LyricWiki fix
* Thu Aug 27 2009 beineri@opensuse.org
- tweak it to keep building against older distros
* Wed Aug 26 2009 mhrusecky@suse.cz
- using up to date errmsg.sys (bnc#528312)
* Tue Aug 18 2009 beineri@opensuse.org
- fix playing of filenames with spaces for gstreamer (bnc#525286)
* Wed Aug  5 2009 cmorve69@yahoo.es
- Backport upstream fix so LyricWiki works again
* Sun Jul 19 2009 beineri@opensuse.org
- update build requires after mysql changes
* Sat Jun 13 2009 beineri@opensuse.org
- update to 2.1.1: several bugfixes and
  * Option to hide the context view.
  * Applets are now laid out according to two criteria: either
    fixed height or flowing to fill the CV. No more slivers of
    applets visible at the bottom.
  * Load contents of an m3u file if specified when running amarok
    from the command line. File must be local.
  * Added large source emblem in current track applet.
  * Make it possible to delete multiple selected playlists at once
    from the "My Playlists" category in the playlist browser.
  * Show info box in CV if no applets are visible.
* Thu Jun  4 2009 beineri@opensuse.org
- don't require errmsg.sys from mysql package (bnc#509815)
* Sat May 30 2009 beineri@opensuse.org
- update to 2.1 release: several bugfixes and
  * Removed the "Amarok Handbook" menu entry until the handbook
    actually exists (work in progress).
  * Single-click/double-click behavior in the Collection Browser
    now follows the preference set in KDE System Settings.
  * Automatically fetch database for Jamendo/Opml on first load.
  * Escape clears most search filters throughout Amarok.
  * Tracks of saved playlists are again shown in playlistbrowser.
    They can be added and sorted using drag and drop.
* Wed May 20 2009 beineri@opensuse.org
- require amarok-lang
* Mon May 18 2009 cmorve69@yahoo.es
- make mp4 support a build option
* Mon May 11 2009 beineri@opensuse.org
- update to 2.1 Beta 2: several bugfixes and
  * New Script method to get current track time in milliseconds.
  * Pressing the return key in the playlist search activates the
    selected result.
  * Pressing escape key in playlist search clears its contents.
  * Optimizations to the insertion and removal of large numbers
    of tracks from the playlist. Especially clearing a large
    playlist is now about 300 times faster.
  * Always scroll to newly inserted tracks in the Playlist.
  * When removing upcoming tracks from an active dynamic playlist,
    add a simmilar number of new ones to keep if from "drying up".
  * Some action cleanup in the playlist context menu.
  * When clearing the playlist, also reset the search/filter text.
  * Podcast titles are stripped of unnecessary whitespace.
* Tue Apr 21 2009 dmueller@suse.de
- kde4-amarok -> amarok
* Thu Apr 16 2009 shrikantkhare@gmail.com
- update to version 2.0.90.svn954151.20090415
- FEATURES:
  * New Script method to get current track time in milliseconds. (bko#177073)
- BUGFIXES:
  * Don't fetch all coverless albums automatically when opening the Cover
    Manager. (bko#176170)
  * Podcast episodes are loaded correctly when restoring a playlist on
    startup. This means the local file will be played if downloaded.
    (bko#189328)
  * Next button in the main toolbar no longer has a clipped shadow.
    (bko#176031)
  * Fixed slider mouse events in RTL layouts. (bko#185465)
  * Detect iPhones as iPods. (bko#184744)
  * Clicking on "Stop after current track" disables the flag if it is
    already enabled.
  * Show a track marker when the "stop after current track" flag is set.
    (bko#185888)
  * Don't flash the OSD when opening the settings dialog. Patch thanks
    to Andreas Heider <andreas@meetr.de>.
  * Podcast file formats are correctly displayed.
  * Don't crash when pressing Delete on empty playlist. (bko#189021)
- VERSION 2.1beta1
  * The collection scanner is now able to be run in batch mode, allowing for
    automated scans of both full and incremental types.  In addition, all
    graphical dependencies have been removed, allowing for headless, remote
    runs of collection scans.  A wiki page detailing how to do this will be
    made available shortly.
  * Covers are shown for iPod collections.
  * Phonon multimedia system can be configured directly from Amarok.
  * Cover art can now be disabled in the collection browser.
  * Scrobble tracks from streams that have title and artist metadata
  * Add support for showing a stream with multiple alternative servers as a
    single item in the playlist and add GUI for manually selecting prefered
    source.
  * Ampache service: Add support for Ampache 3.5.x as well as 3.4.4.
  * Auto timecoding (position bookmarking) now exists for tracks with length
    greater than 10 minutes. (bko#148740)
  * Add a animated "loading..." screen when dynamically fetching info about
    an item to show in the service info applet.
  * Deleting tracks from the local collection is now possible. (bko#170999)
  * Add a filter-by-date-added to the collection browser. Use added:"today"
    or added:<2m2d
  * Add a tab bar in the current track applet for showing also the favorite
    tracks in the collection.
  * Add an advanced but user friendly playlist layout editor allowing users
    to modify and create their own playlist layouts.
  * The Playlist can now render itself using layouts defined in XML. A
    number of default layouts are included and can be switched between.
  * Option to automatically scroll the playlist to the active item on track
    change.
  * New QtScript methods for accessing the playlist:
    Amarok.Playlist.selectedFilenames() & Amarok.Playlist.selectedIndizes().
  Patch by Mathias Panzenböck <grosser.meister.morti@gmx.net>.
  * New QtScript method for the Track prototype: imagePixmap( size ). Returns
    a QPixmap of the given size, or the default if the size argument isn't
    supplied.
  * New QtScript class 'DataDownloader' that returns results as a QByteArray
    instead of a string. Needed for image downloads.
  * Cue Sheets are now supported as in Amarok 1.4, plus each cue entry
    (usually a track) will be displayed as a timecode on the Progress Bar
  with a nice onMouseOver popup.
  * Ipod support now uses/depends on libgpod 0.7.0
  * Bookmarking specific positions within local tracks and downloaded local
    podcast episodes, with a nice visual indicator on the progress bar.
  * When the last.fm service is active, any track, from any collection or
    service, can be loved from the browser , and there will always be a love
    button for the currently playing track, no matter the source.
  * Dbus methods added: VolumeUp, VolumeDown and Mute. (bko#181130)
  * The feed url is displayed in the config dialog of a podcast channel.
    By left clicking in the url it's copied to the clipboard. (bko#180853)
  * The Playlist Browser can now show playlists from multiple sources,
    including media devices.
  * The last.fm service now allows for the playing of all types of user
    stations (personal, loved tracks, recommendations, and neighborhood).
  * Arbitrary Tags can now be played in the last.fm service. (bko#139802)
  * Replay Gain support for most file formats that Amarok can read tags from.
    Reading Replay Gain tags from MP4 files requires libMP4v2.  Musepack
    (MPC) files are unsupported due to a limitation of TagLib.
  * Amarok urls. Amarok can now load and generate "amarok urls" that allows
    any "view" to be bookmarked and later retrieved. A protocol handler is
    also installed that will launch amarok into the correct state, or make
    amarok show the correct view if already running if such a url is
    activated system wide.
  * Customizable playlist layouts. The playlist is now rendered according to
    an xml layout, allowing the playlist to assume a variety of different
    looks and supply customizable information.
  * Album cover art can be accessed via the scripting API. Patch thanks to
    Simon Esneault <simon.esneault@gmail.com>. (bko#179732)
  * New vertical Context View layout.
  * New applet toolbar in the Context View to arrange, select, and add applets.
* Thu Apr  9 2009 rhafer@suse.de
- included upstream fix for broken last.fm authentication (kde#188678)
* Fri Mar  6 2009 wstephenson@suse.de
- update to 2.0.2
  * Show a statusbar message when loving a lastfm track.
  * Show error message when Wikipedia information cannot be retrieved.
  * Fix showing of book information from the LibriVox service.
  * Don't crash if a script has uncaught exceptions.
  * Open ogg files in Amarok when using Dolphin and other file
    managers. Patch thanks to Lubos Lunak. (kde#180155)
  * Fix podcast episodes not ordered right because of incorrect
    parsing of pubdate. (kde#181338)
  * Fix crash in tagdialog when editing tracks without an artist.
    (kde#183180)
  * Statistics were not calculated properly in all instances.
    (kde#182025)
  * Compilation fixes on Open Solaris.
  * Trim URL before adding a new podcast.
  * Add Ok button to the podcast configuration dialog to improve usability.
    (kde#181339)
  * Add tooltips to now playing widget icons.
  * Fix not possible to download episodes from newly added podcast channel.
    (kde#180851)
* Mon Mar  2 2009 coolo@suse.de
- compile with gcc 4.4
* Sat Jan 10 2009 stbinner@suse.de
- update to 2.0.0.1: fix possible buffer overflows when parsing
  Audible .aa files (bnc#465098)
* Fri Jan  9 2009 llunak@suse.cz
- add more variants of ogg mimetypes to amarok.desktop (bnc#438718)
* Tue Jan  6 2009 stbinner@suse.de
- update to 2.0.1
  * Add advanced, configurable, searching and filtering to playlist.
  * Add "Stop after track" option to the playlist menu.
  * Queue track functionality has returned.
  * Add automatic recovery option to MySQL embedded server.
  * Greatly improved Librivox.org service script. It now works for
    all books, and dynamically fetches a summary of each book that
    is shown in the service info applet. The script now also has a
    propper icon in the service browser and its own emblem and
    default "album" cover for books.
  * Sorting collection by Composer is now possible.
  * Service scripts can now dynamically fetch context info when
    items are selected (info can still be applied statically to
    each item as well).
  * Album items from a service script can now have custom covers.
  * Items from a service script can now have a custom emblem.
  * Service scripts can now set custom icons for the service browser.
  * Add simple filtering to the service browser.
  * Podcast channels are automatically refreshed once per hour if
    autoscan is enabled.
* Wed Dec 31 2008 stbinner@suse.de
- gdkpixbuf is required for pod support
* Tue Dec 30 2008 stbinner@suse.de
- don't require errmsg.sys from mysql package (bnc#450318)
* Mon Dec 15 2008 dmueller@suse.de
- add missing requirement on qt4-sql-sqlite
- use mysql embedded instead of mysql server
* Sun Dec 14 2008 meissner@suse.de
- fixed a crash with MTP devices without sufficient permissions.
  bnc#457931
* Sat Dec  6 2008 stbinner@suse.de
- update to Amarok 2.0 final release tarball plus official patches:
  CHANGES:
  * Removed the KBookmarks menu in the FileBrowser because it
    causes crashes.
  * The Organize Collection dialog has been improved.
  * Last.Fm service now uses KIO for network access, respects
    desktop proxy settings.
  BUGFIXES:
  * Fix bug that showed misplaced applets in the Context View
    after resizing the window and changing to another containment.
  * Don't try to squeeze text into wrongly tiny space, make the track
    label in the tag dialog work again.
  * Collection setup directory chooser would incorrectly set some paths as
    disabled. Patch thanks to Ben Boeckel <MathStuf@gmail.com>.
  * Fix shadows around the cover in the current track applet (and
    potentially other places as well) getting progresssively darker.
  * Don't compare Solid and libmtp's serial number to connect.
  * Workaround a bug in the CurrentEngine class that makes the nocover image
    look grainy in the currenttrack applet.
  * Dragging and Dropping folders from the filebrowser into the playlist will
    now result in the tracks being ordered correctly.
  * Fixed deletion for downloaded podcast episodes
  * Show artists in Cover Manager sorted alphabetically.
  * Fix reading of windows playlists, recognise \ as directory separator.
  * Fix crash when searching in collections.
  * Prevent disabled MP3tunes service from being initialized on first run.
  * Elide text properly in applet chooser widget.
  * Fixed potential crash when playing streams.
  * Don't show wrong metadata for Last.fm radio.
  * Don't try to squeeze text into wrongly tiny space, make the track label
    in the tag dialog work again.
  * Expand applets width when a complete column has been removed.
  * Don't try to fetch another cover if there are no more albums to fetch
    for.
  * Don't crash when trying to edit the details of a track without an artist
    or album.
* Fri Nov 28 2008 stbinner@suse.de
- update to post-RC1 snapshot tarball provided by Amarok team:
  FEATURES:
  * Added read/write configuration APIs for Qtscript.
  CHANGES:
  * Added icons to the filename scheme and organize collection dialogs.
  * Added an OK button for the script manager.
  BUGFIXES:
  * Magnatune.com store: Correctly show progress info when downloading.
  * Magnatune.com store: Fix purchase/download of wrong album being initiated
    when selecting "Purchase" or "Download" from the playlist context menu.
  * Fix a bug that stopping a running script crashes amarok.
  * The context view could sometimes show the "stopped state" even when
    a track was playing.
  * Amarok 1.4 database importer would crash under some circumstances.
  * Covers could not be fetched from Amazon Japan.
  * Fix a bug that the script manager deletes wrong entry after script
    installation.
  * Make lyrics auto-display when applet is added while a song is playing.
  * "Watch folders for changes" actually works now
  * Fix a bug that caused dynamic playlists not to repopulate.
  * Fixed potential issues with malformed XML breaking the collection scan.
  * Focus of text fields no longer lost when changing tracks using the Next/
    Previous buttons in tag dialog.
  * Sort Podcasts in the right order.
* Fri Nov 21 2008 stbinner@suse.de
- update to 1.98 (2.0 Release Candidate 1)
  FEATURES:
  * Users' Recommended radio is now shown in the Last.Fm Service.
  * Playlist browser items can be deleted and renamed using the keyboard.
  * Basic and Advanced view when editing a filename scheme are synchronized.
  * Added delete button to Advanced view for defining a filename scheme.
  * Importer for iTunes libraries now allows you to import your statistics
    from iTunes.
  * The settings dialog now remembers the page that was last used.
  * Track information can be edited from the file browser.
  CHANGES:
  * Video and Last.fm applet have been disabled. They are not ready for release.
  * Ipods and MTP devices auto-connect again for usability.
  * Ipod Collections can now delete multiple tracks at once.
  * User playlists added from files are now updated on collection rescans, so
    any changes in the file is reflected in the SQL playlist.
  * Layout refactoring in the Organize Collection dialog.
  * Enabled Last.fm scrobbling by default when Last.fm login is supplied.
  * Amarok now allows opening of video files again.
  * "Show active track" has been moved from the playlist context menu to the
    playlist toolbar.
  BUGFIXES: too many to copy them all here :-)
* Wed Nov 12 2008 dmueller@suse.de
- call post_install hook to update desktop translations
* Wed Nov  5 2008 dmueller@suse.de
- use minimal-toc to fix build on ppc(64)
* Tue Nov  4 2008 stbinner@suse.de
- update to 1.94 (2.0 Beta 3):
  * playlist and statusbar recieved major attention
  * database/statistics import from Amarok 1.4
  * major overhaul of the Last.fm integration
  * sorting by year and album in the Collection Browser is
    possible again (small, but often requested)
  * shortcut to jump to current track in the playlist
  * many, many bugs squashed and stability fixes
* Thu Oct 16 2008 stbinner@suse.de
- split off kde4-amarok-lang package
* Mon Oct  6 2008 dmueller@suse.de
- update to 1.92.2 (2.0 Beta2)
  * music database is now using mysql embedded
  * various fixes / new features
* Tue Sep  9 2008 dmueller@suse.de
- fix uninitialized return value warnings
* Wed Aug 20 2008 dmueller@suse.de
- update to 1.90 (2.0 Beta1)
* Mon Jul 21 2008 dmueller@suse.de
- update to 1.86 (2.0 Alpha2)
* Wed Jul  9 2008 dmueller@suse.de
- update to 1.83 (2.0 Alpha1)
* Thu Jun 26 2008 dmueller@suse.de
- update to 4.0.84.svn824686
* Tue Jun 24 2008 dmueller@suse.de
- update to 4.0.81.svn823998
* Tue Jun  3 2008 dmueller@suse.de
- update to 4.0.81.svn816194
* Thu May 15 2008 dmueller@suse.de
- update to 4.0.74.svn808129
* Wed May  7 2008 dmueller@suse.de
- update to 4.0.73.svn805196
* Thu Apr 24 2008 dmueller@suse.de
- update to 4.0.71.svn800684
* Fri Apr 18 2008 dmueller@suse.de
- update to 4.0.69.svn798537
* Wed Apr  2 2008 dmueller@suse.de
- update to 4.0.68.svn792936
* Thu Feb 14 2008 dmueller@suse.de
- update to 4.0.62.svn775117
* Wed Nov 28 2007 dmueller@suse.de
- update to 3.96.0.svn742626
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.0.svn731749
